<?php

namespace domain\Product\Product;

use domain\_\AbstractManager;
use domain\Distribution\Distribution\Distribution;
use domain\Distribution\ProductDistribution\ProductDistributionBuilder;
use domain\Product\Accessory\Accessory;
use domain\Product\ProductAccessory\ProductAccessoryManager;

class ProductManager extends AbstractManager
{
    protected ProductAccessoryManager $productAccessoryManager;
    protected ProductDistributionBuilder $productDistributionBuilder;

    public function loadDependencies(): void
    {
        $this->productAccessoryManager = $this->loadService(ProductAccessoryManager::class);
        $this->productDistributionBuilder = $this->loadService(ProductDistributionBuilder::class);
    }

    public function activateProductInDistribution(Product $product, Distribution $distribution)
    {
        $productDistribution = $this->productDistributionBuilder->createProductDistributionIfNotExist($distribution, $product);
        $this->productDistributionBuilder->updateProductDistributionActive($productDistribution, 1);
    }

    public function deactivateProductInDistribution(Product $product, Distribution $distribution)
    {
        $productDistribution = $this->productDistributionBuilder->createProductDistributionIfNotExist($distribution, $product);
        $this->productDistributionBuilder->updateProductDistributionActive($productDistribution, 0);
    }

    public function needAccessory(Product $product, Accessory $accessory, int $quantity): void
    {
        $this->productAccessoryManager->createProductAccessoryIfNotExist($product, $accessory, $quantity);
    }
}