<?php

namespace domain\Subscription\ProductSubscription;

use domain\_\AbstractManager;
use domain\Product\Product\Product;
use domain\Product\Rotating\Rotating;
use domain\Subscription\Subscription\Subscription;
use yii\base\ErrorException;

class ProductSubscriptionManager extends AbstractManager
{
    protected ProductSubscriptionBuilder $productSubscriptionBuilder;

    public function loadDependencies(): void
    {
        $this->productSubscriptionBuilder = $this->loadService(ProductSubscriptionBuilder::class);
    }

    public function createProductSubscription(Subscription $subscription, Product $product = null, Rotating $rotating = null, float $quantity = null): ProductSubscription
    {
        if(!$product && !$rotating) {
            throw new ErrorException("Il faut au moins un produit ou un produit tournant pour créer un ProductSubscription");
        }

        $productSubscription = $this->productSubscriptionBuilder->instanciateProductSubscription($subscription);
        if($product) {
            $productSubscription->setProduct($product);
        }
        if($rotating) {
            $productSubscription->setRotating($rotating);
        }
        $productSubscription->setQuantity($quantity);

        $productSubscription->save();

        return $productSubscription;
    }
}