<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace backend\controllers;

use domain\Feature\Feature\Feature;
use domain\Product\Rotating\Rotating;
use yii\filters\AccessControl;
use yii\helpers\Html;
use yii\web\NotFoundHttpException;
use yii\web\Response;

class RotatingController extends BackendController
{
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::class,
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['@'],
                        'matchCallback' => function ($rule, $action) {
                            return $this->getUserModule()
                                ->getAuthorizationChecker()
                                ->isGrantedAsProducer($this->getUserCurrent())

                                && $this->getFeatureModule()->getChecker()
                                    ->isEnabled(Feature::ALIAS_ROTATING_PRODUCT);
                        }
                    ]
                ],
            ],
        ];
    }

    public function actionIndex()
    {
        return $this->render('index', [
            'dataProvider' => $this->getRotatingModule()->getRepository()
                ->queryRotatings()->getDataProvider(20),
        ]);
    }

    public function actionCreate()
    {
        $rotatingModule = $this->getRotatingModule();
        $rotatingModel = $rotatingModule->getBuilder()->instanciateRotating($this->getProducerCurrent());

        if ($rotatingModel->load(\Yii::$app->request->post()) && $rotatingModel->validate()) {
            $rotating = $rotatingModule->getManager()->createRotating(
                $this->getProducerCurrent(),
                $rotatingModel->getName(),
                $rotatingModel->getDay(),
                $rotatingModel->getSelectedProductsIds()
            );
            $this->setFlash('success', "Produit tournant <strong>".Html::encode($rotating->getName())."</strong> ajouté");
            return $this->redirectAfterSave('rotating', $rotating->getId());
        }

        return $this->render('create', [
            'rotatingModel' => $rotatingModel,
            'rotating' => $this->initFormModel($rotatingModel),
            'productsArray' => $this->findProducts()
        ]);
    }

    public function actionUpdate(int $id)
    {
        $rotating = $this->findRotating($id);

        if ($rotating->load(\Yii::$app->request->post()) && $rotating->validate()) {
            $this->getRotatingModule()->getManager()->updateRotating(
                $rotating,
                $rotating->getSelectedProductsIds()
            );
            $this->setFlash('success', "Produit tournant <strong>".Html::encode($rotating->getName())."</strong> modifié");
            return $this->redirectAfterSave('rotating', $rotating->getId());
        }

        return $this->render('update', [
            'rotatingModel' => $rotating,
            'rotating' => $this->initFormModel($rotating),
            'productsArray' => $this->findProducts()
        ]);
    }

    public function actionDelete(int $id): Response
    {
        $rotatingModule = $this->getRotatingModule();
        $rotating = $this->findRotating($id);
        if($rotatingModule->getManager()->deleteRotating($rotating)) {
            $this->setFlash('success', "Produit tournant supprimé");
        }

        return $this->redirect('index');
    }

    protected function findRotating($id): Rotating
    {
        if (($rotating = $this->getRotatingModule()->getRepository()->findOneRotatingById($id)) !== null) {
            return $rotating;
        } else {
            throw new NotFoundHttpException("Le produit tournant n'a pas été trouvé.");
        }
    }

    public function findProducts(): array
    {
        return $this->getProductModule()->getRepository()->findProducts(true);
    }

    public function initFormModel(Rotating $rotating)
    {
        $this->getRotatingModule()->getBuilder()->initSelectedProductsIds($rotating);
        return $rotating;
    }
}
