<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace domain\Subscription\ProductSubscription;

use common\components\ActiveRecordCommon;
use domain\Product\Product\Product;
use domain\Product\Rotating\Rotating;
use domain\Subscription\Subscription\Subscription;
use yii\db\ActiveQuery;

class ProductSubscription extends ActiveRecordCommon
{
    public static function tableName()
    {
        return 'product_subscription';
    }

    public function rules()
    {
        return [
            [['id_subscription'], 'required'],
            [['id_subscription', 'id_product', 'id_rotating'], 'integer'],
            [['quantity'], 'number'],
        ];
    }

    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'id_subscription' => 'Abonnement',
            'id_product' => 'Produit',
            'id_rotating' => 'Produit tournant',
            'quantity' => 'Quantité',
        ];
    }

    /* Méthodes */



    /* Getters / setters */

    public function getRotating(): ?Rotating
    {
        return $this->rotatingRelation;
    }

    public function setRotating(Rotating $rotating): self
    {
        $this->populateFieldObject('id_rotating', 'rotatingRelation', $rotating);
        return $this;
    }

    public function getSubscription(): Subscription
    {
        return $this->subscriptionRelation;
    }

    public function setSubscription(Subscription $subscription): self
    {
        $this->populateFieldObject('id_subscription', 'subscriptionRelation', $subscription);
        return $this;
    }

    public function getProduct(): ?Product
    {
        return $this->productRelation;
    }

    public function setProduct(Product $product): self
    {
        $this->populateFieldObject('id_product', 'product', $product);
        return $this;
    }

    public function getQuantity(): float
    {
        return $this->quantity;
    }

    public function setQuantity(float $quantity): self
    {
        $this->quantity = $quantity;
        return $this;
    }

    /* Relations */

    public function getRotatingRelation(): ActiveQuery
    {
        return $this->hasOne(Rotating::class, ['id' => 'id_rotating']);
    }

    public function getProductRelation(): ActiveQuery
    {
        return $this->hasOne(Product::class, ['id' => 'id_product']);
    }
}
